==> knative-model-4.12.0-sources.jar: annotations/io/fabric8/knative/eventing/contrib/gitlab/v1alpha1/GitLabSourceSpecFluent.java <==
package io.fabric8.knative.eventing.contrib.gitlab.v1alpha1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluent;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface GitLabSourceSpecFluent<A extends GitLabSourceSpecFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildAccessToken instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource getAccessToken();
    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource buildAccessToken();
    public A withAccessToken(io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource accessToken);
    public Boolean hasAccessToken();
    public GitLabSourceSpecFluent.AccessTokenNested<A> withNewAccessToken();
    public GitLabSourceSpecFluent.AccessTokenNested<A> withNewAccessTokenLike(io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource item);
    public GitLabSourceSpecFluent.AccessTokenNested<A> editAccessToken();
    public GitLabSourceSpecFluent.AccessTokenNested<A> editOrNewAccessToken();
    public GitLabSourceSpecFluent.AccessTokenNested<A> editOrNewAccessTokenLike(io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource item);
    public A addToEventTypes(int index,String item);
    public A setToEventTypes(int index,String item);
    public A addToEventTypes(String... items);
    public A addAllToEventTypes(Collection<String> items);
    public A removeFromEventTypes(String... items);
    public A removeAllFromEventTypes(Collection<String> items);
    public List<String> getEventTypes();
    public String getEventType(int index);
    public String getFirstEventType();
    public String getLastEventType();
    public String getMatchingEventType(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingEventType(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withEventTypes(List<String> eventTypes);
    public A withEventTypes(String... eventTypes);
    public Boolean hasEventTypes();
    public A addNewEventType(String arg1);
    public A addNewEventType(StringBuilder arg1);
    public A addNewEventType(StringBuffer arg1);
    public String getProjectUrl();
    public A withProjectUrl(String projectUrl);
    public Boolean hasProjectUrl();
    public A withNewProjectUrl(String arg1);
    public A withNewProjectUrl(StringBuilder arg1);
    public A withNewProjectUrl(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildSecretToken instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource getSecretToken();
    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource buildSecretToken();
    public A withSecretToken(io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource secretToken);
    public Boolean hasSecretToken();
    public GitLabSourceSpecFluent.SecretTokenNested<A> withNewSecretToken();
    public GitLabSourceSpecFluent.SecretTokenNested<A> withNewSecretTokenLike(io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource item);
    public GitLabSourceSpecFluent.SecretTokenNested<A> editSecretToken();
    public GitLabSourceSpecFluent.SecretTokenNested<A> editOrNewSecretToken();
    public GitLabSourceSpecFluent.SecretTokenNested<A> editOrNewSecretTokenLike(io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource item);
    public String getServiceAccountName();
    public A withServiceAccountName(String serviceAccountName);
    public Boolean hasServiceAccountName();
    public A withNewServiceAccountName(String arg1);
    public A withNewServiceAccountName(StringBuilder arg1);
    public A withNewServiceAccountName(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildSink instead.
 * @return The buildable object.
 */
@Deprecated public Destination getSink();
    public Destination buildSink();
    public A withSink(Destination sink);
    public Boolean hasSink();
    public GitLabSourceSpecFluent.SinkNested<A> withNewSink();
    public GitLabSourceSpecFluent.SinkNested<A> withNewSinkLike(Destination item);
    public GitLabSourceSpecFluent.SinkNested<A> editSink();
    public GitLabSourceSpecFluent.SinkNested<A> editOrNewSink();
    public GitLabSourceSpecFluent.SinkNested<A> editOrNewSinkLike(Destination item);
    public Boolean isSslverify();
    public A withSslverify(Boolean sslverify);
    public Boolean hasSslverify();
    public A withNewSslverify(String arg1);
    public A withNewSslverify(boolean arg1);
    public interface AccessTokenNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSourceFluent<GitLabSourceSpecFluent.AccessTokenNested<N>> {

        public N and();
        public N endAccessToken();    }


    public interface SecretTokenNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSourceFluent<GitLabSourceSpecFluent.SecretTokenNested<N>> {

        public N and();
        public N endSecretToken();    }


    public interface SinkNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DestinationFluent<GitLabSourceSpecFluent.SinkNested<N>> {

        public N and();
        public N endSink();    }


}

==> knative-model-5.0.2-sources.jar: annotations/io/fabric8/knative/eventing/contrib/gitlab/v1alpha1/GitLabSourceSpecFluent.java <==
package io.fabric8.knative.eventing.contrib.gitlab.v1alpha1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluent;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface GitLabSourceSpecFluent<A extends GitLabSourceSpecFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildAccessToken instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource getAccessToken();
    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource buildAccessToken();
    public A withAccessToken(io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource accessToken);
    public Boolean hasAccessToken();
    public GitLabSourceSpecFluent.AccessTokenNested<A> withNewAccessToken();
    public GitLabSourceSpecFluent.AccessTokenNested<A> withNewAccessTokenLike(io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource item);
    public GitLabSourceSpecFluent.AccessTokenNested<A> editAccessToken();
    public GitLabSourceSpecFluent.AccessTokenNested<A> editOrNewAccessToken();
    public GitLabSourceSpecFluent.AccessTokenNested<A> editOrNewAccessTokenLike(io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource item);
    public A addToEventTypes(int index,String item);
    public A setToEventTypes(int index,String item);
    public A addToEventTypes(String... items);
    public A addAllToEventTypes(Collection<String> items);
    public A removeFromEventTypes(String... items);
    public A removeAllFromEventTypes(Collection<String> items);
    public List<String> getEventTypes();
    public String getEventType(int index);
    public String getFirstEventType();
    public String getLastEventType();
    public String getMatchingEventType(Predicate<String> predicate);
    public Boolean hasMatchingEventType(Predicate<String> predicate);
    public A withEventTypes(List<String> eventTypes);
    public A withEventTypes(String... eventTypes);
    public Boolean hasEventTypes();
    public A addNewEventType(String arg1);
    public A addNewEventType(StringBuilder arg1);
    public A addNewEventType(StringBuffer arg1);
    public String getProjectUrl();
    public A withProjectUrl(String projectUrl);
    public Boolean hasProjectUrl();
    public A withNewProjectUrl(String arg1);
    public A withNewProjectUrl(StringBuilder arg1);
    public A withNewProjectUrl(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildSecretToken instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource getSecretToken();
    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource buildSecretToken();
    public A withSecretToken(io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource secretToken);
    public Boolean hasSecretToken();
    public GitLabSourceSpecFluent.SecretTokenNested<A> withNewSecretToken();
    public GitLabSourceSpecFluent.SecretTokenNested<A> withNewSecretTokenLike(io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource item);
    public GitLabSourceSpecFluent.SecretTokenNested<A> editSecretToken();
    public GitLabSourceSpecFluent.SecretTokenNested<A> editOrNewSecretToken();
    public GitLabSourceSpecFluent.SecretTokenNested<A> editOrNewSecretTokenLike(io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource item);
    public String getServiceAccountName();
    public A withServiceAccountName(String serviceAccountName);
    public Boolean hasServiceAccountName();
    public A withNewServiceAccountName(String arg1);
    public A withNewServiceAccountName(StringBuilder arg1);
    public A withNewServiceAccountName(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildSink instead.
 * @return The buildable object.
 */
@Deprecated public Destination getSink();
    public Destination buildSink();
    public A withSink(Destination sink);
    public Boolean hasSink();
    public GitLabSourceSpecFluent.SinkNested<A> withNewSink();
    public GitLabSourceSpecFluent.SinkNested<A> withNewSinkLike(Destination item);
    public GitLabSourceSpecFluent.SinkNested<A> editSink();
    public GitLabSourceSpecFluent.SinkNested<A> editOrNewSink();
    public GitLabSourceSpecFluent.SinkNested<A> editOrNewSinkLike(Destination item);
    public Boolean isSslverify();
    public A withSslverify(Boolean sslverify);
    public Boolean hasSslverify();
    public A withNewSslverify(String arg1);
    public A withNewSslverify(boolean arg1);
    public interface AccessTokenNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSourceFluent<GitLabSourceSpecFluent.AccessTokenNested<N>> {

            public N and();
            public N endAccessToken();    }


    public interface SecretTokenNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSourceFluent<GitLabSourceSpecFluent.SecretTokenNested<N>> {

            public N and();
            public N endSecretToken();    }


    public interface SinkNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DestinationFluent<GitLabSourceSpecFluent.SinkNested<N>> {

            public N and();
            public N endSink();    }


}
